package com.ruoyi.manage.mapper;

import java.util.List;
import com.ruoyi.manage.domain.RecordInspectionTask;
import org.springframework.stereotype.Repository;
/**
 * 巡检机位信息Mapper接口
 *
 * @author wangh
 * @date 2024-09-25
 */
@Repository
public interface RecordInspectionTaskMapper
{
    /**
     * 查询巡检机位信息
     *
     * @param objid 巡检机位信息主键
     * @return 巡检机位信息
     */
    public RecordInspectionTask selectRecordInspectionTaskByObjid(Long objid);

    /**
     * 查询巡检机位信息列表
     *
     * @param recordInspectionTask 巡检机位信息
     * @return 巡检机位信息集合
     */
    public List<RecordInspectionTask> selectRecordInspectionTaskList(RecordInspectionTask recordInspectionTask);

    /**
     * 新增巡检机位信息
     *
     * @param recordInspectionTask 巡检机位信息
     * @return 结果
     */
    public int insertRecordInspectionTask(RecordInspectionTask recordInspectionTask);

    /**
     * 修改巡检机位信息
     *
     * @param recordInspectionTask 巡检机位信息
     * @return 结果
     */
    public int updateRecordInspectionTask(RecordInspectionTask recordInspectionTask);

    /**
     * 删除巡检机位信息
     *
     * @param objid 巡检机位信息主键
     * @return 结果
     */
    public int deleteRecordInspectionTaskByObjid(Long objid);

    /**
     * 批量删除巡检机位信息
     *
     * @param objids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordInspectionTaskByObjids(String[] objids);
}
